==> qtjambi-pdf-debuginfo-macos-6.6.0.jar: sources/QtJambiPdf/QPdfPageNavigator_shell.h <==
#ifndef QPDFPAGENAVIGATOR_SHELL_H
#define QPDFPAGENAVIGATOR_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtPdf/qpdfpagenavigator.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtPdf/qpdflink.h>
#include <QtJambi/RegistryAPI>


class QPdfPageNavigator_shell : public QPdfPageNavigator, public QtJambiShellInterface
{
public:
    QPdfPageNavigator_shell();
    QPdfPageNavigator_shell(QObject* parent0);
    ~QPdfPageNavigator_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPdfPageNavigator_access : public QPdfPageNavigator
{
    jobject __qt_currentLink(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QPDFPAGENAVIGATOR_SHELL_H

==> qtjambi-pdf-debuginfo-macos-6.6.3.jar: sources/QtJambiPdf/QPdfPageNavigator_shell.h <==
#ifndef QPDFPAGENAVIGATOR_SHELL_H
#define QPDFPAGENAVIGATOR_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtPdf/qpdfpagenavigator.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtPdf/qpdflink.h>
#include <QtJambi/RegistryAPI>


class QPdfPageNavigator_shell : public QPdfPageNavigator, public QtJambiShellInterface
{
public:
    QPdfPageNavigator_shell();
    QPdfPageNavigator_shell(QObject* parent0);
    ~QPdfPageNavigator_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPdfPageNavigator_access : public QPdfPageNavigator
{
    jobject __qt_currentLink_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QPDFPAGENAVIGATOR_SHELL_H
